from distutils.core import setup

setup(
        name        = 'nesterhyb',
        version     = '1.0.0',
        py_modules  = ['nesterhyb'],
        author      = 'hybdev',
        author_email= 'beenyee@163.com',
        description = 'A simple printer of nested list',
    )
